@@ -768,7 +768,6 @@ class AWSpider:
         reactor.callLater( 5, self.checkPeers )
     
     def checkPeers( self ):
-        logger.debug( sdb_now( offset=self.time_offset) )
         sql = "SELECT public_ip, local_ip, port FROM %s WHERE created > '%s'" % ( self.aws_sdb_coordination_domain, sdb_now_add( self.peer_check_interval * -2, offset=self.time_offset) )
         #logger.debug( "Querying SimpleDB, \"%s\"" % sql )
         d = self.sdb.select( sql )
@@ -787,6 +786,7 @@ class AWSpider:
         for uuid in new_peers:
             if uuid == self.uuid:
                 self.peers[uuid] = {
+                    "uri":"http://127.0.0.1:%s" % self.port,
                     "local_ip":"127.0.0.1",
                     "port":self.port
                 }
